@@ -11,7 +11,7 @@ export class DjangoService {
     private urlInput: HTMLInputElement = document.querySelector('#id_link_url');
     private labelInput: HTMLInputElement = document.querySelector('#id_link_label');
     private linkTypeInput: HTMLSelectElement = document.querySelector('#id_link_type');
-    
+
     private urlLinkType: LinkType = {name: 'url', verboseName: 'URL', isGenericForeignKey: false, placeholder: 'https://example.com', isShowUrl: false};
 
     getDefaultLinkType(): LinkType {
@@ -42,9 +42,9 @@ export class DjangoService {
             component.linkType = linkTypeMatched;
         }
     }
-    
+
     save(linkTypes: Array<LinkType>, linkType: LinkType, instance: LinkInstance, linkUrl: string) {
-        if (linkType.urlPrefix) {
+        if (linkType.urlPrefix && !linkUrl.startsWith(linkType.urlPrefix)) {
             this.urlInput.value = linkType.urlPrefix + linkUrl;
         } else {
             this.urlInput.value = linkUrl;
@@ -68,7 +68,7 @@ export class DjangoService {
             this.linkTypeInput.value = 'generic_foreign_key';
         }
     }
-    
+
     async fetchInstancesSelectable(linkType: LinkType): Promise<Array<LinkInstance>> {
         let instancesSelectable: Array<LinkInstance> = [];
         if (linkType.isGenericForeignKey) {
@@ -82,7 +82,7 @@ export class DjangoService {
         }
         return instancesSelectable;
     }
-    
+
     async getLinkTypes(): Promise<Array<LinkType>> {
         const response: AxiosResponse = await axios.get('/link-types/');
         const linkFkTypes: Array<LinkType> = response.data.map(type => { return {
@@ -112,7 +112,7 @@ export class DjangoService {
             },
             {
                 name: 'anchor',
-                verboseName: 'Phone',
+                verboseName: 'Anchor',
                 isGenericForeignKey: false,
                 urlPrefix: '#',
                 placeholder: 'anchor-example',
